@@ -2,6 +2,7 @@
 # Copyright (c) 2011 gocept gmbh & co. kg
 # See also LICENSE.txt
 
+from Products.ZReST.ZReST import manage_addZReST
 from gocept.fssyncz2.testing import unsnarf, grep
 import Missing
 import OFS.SimpleItem
@@ -10,10 +11,9 @@ import Testing.ZopeTestCase
 import doctest
 import gocept.fssyncz2.main
 import gocept.fssyncz2.testing
-import gocept.fssyncz2.traversing
 import httplib
 import lxml
-import os.path
+import os
 import pickle
 import pyquery
 import random
@@ -23,8 +23,6 @@ import transaction
 import unittest
 import urllib2
 import zope.app.fssync.main
-import zope.fssync.synchronizer
-import zope.fssync.tests.test_task
 import zope.testbrowser.browser
 
 
@@ -38,8 +36,8 @@ class Zope2ObjectsTest(unittest.TestCase):
             pickle.dumps({'foo': Missing.Value})
         except TypeError, e:
             self.fail(e)
-        self.assert_("(dp0\nS'foo'\np1\nNs.",
-                     repr(pickle.dumps({'foo': Missing.Value})))
+        self.assertEqual(
+            "(dp0\nS'foo'\np1\nNs.", pickle.dumps({'foo': Missing.Value}))
 
 
 class ViewTests(Testing.ZopeTestCase.FunctionalTestCase):
@@ -195,42 +193,39 @@ class FolderTest(Testing.ZopeTestCase.FunctionalTestCase):
         self.assertEquals("""\
   <entry name="foo"
 """, grep('<entry', unsnarf(response, 'folder/@@Zope/Entries.xml')))
-        self.assertTrue("""\
+        self.assertTrue("""
+  <dictionary>
+    <item key="__ac_local_roles__">
         <dictionary>
-          <item key="__ac_local_roles__">
-              <dictionary>
-                <item key="test_user_1_">
-                    <list>
-                      <string>Owner</string>
-                    </list>
-                </item>
-              </dictionary>
-          </item>
-          <item key="_owner">
-              <tuple>
-                <list>
-                  <string>test_folder_1_</string>
-                  <string>acl_users</string>
-                </list>
-                <string>test_user_1_</string>
-              </tuple>
-          </item>
-          <item>
-            <key> <string>a</string> </key>
-            <value> <string>asdf</string> </value>
-          </item>
-          <item>
-            <key> <string>b</string> </key>
-            <value> <string>bsdf</string> </value>
-          </item>
-          <item key="id">
-              <string>folder</string>
-          </item>
-          <item key="title">
-              <string></string>
+          <item key="test_user_1_">
+              <list>
+                <string>Owner</string>
+              </list>
           </item>
         </dictionary>
-""", unsnarf(response, '@@Zope/Extra/folder/attributes'))
+    </item>
+    <item key="_owner">
+        <tuple>
+          <list>
+            <string>test_folder_1_</string>
+            <string>acl_users</string>
+          </list>
+          <string>test_user_1_</string>
+        </tuple>
+    </item>
+    <item>
+      <key> <string>a</string> </key>
+      <value> <string>asdf</string> </value>
+    </item>
+    <item>
+      <key> <string>b</string> </key>
+      <value> <string>bsdf</string> </value>
+    </item>
+    <item key="title">
+        <string></string>
+    </item>
+  </dictionary>
+""" in unsnarf(response, '@@Zope/Extra/folder/attributes').getvalue())
 
     def test_folder_attributes_are_unpickled(self):
         snarf = """\
@@ -306,6 +301,22 @@ class FolderTest(Testing.ZopeTestCase.FunctionalTestCase):
                          repr(self.app['folder2']['foo']))
         self.assertEqual('bar', self.app['folder2']['foo'].data)
 
+    def test_items_in_ignore_file_are_not_dumped(self):
+        self.app.manage_addFolder('folder')
+        self.app['folder'].manage_addFile('foo', 'one')
+        self.app['folder'].manage_addFile('bar', 'two')
+        self.app['folder'].manage_addFile('baz', 'three')
+        manage_addZReST(self.app['folder'], 'fssync-dump-ignore')
+        ignore = self.app['folder']['fssync-dump-ignore']
+        ignore.source = 'bar\nbaz'
+        response = self.publish(
+            '/folder/@@toFS.snarf', basic='manager:asdf')
+        self.assertEquals("""\
+  <entry name="foo"
+  <entry name="fssync-dump-ignore"
+""", grep('<entry', unsnarf(response, 'folder/@@Zope/Entries.xml'),
+          sort=True))
+
 
 class PythonScriptTest(Testing.ZopeTestCase.FunctionalTestCase):
     """Make sure leaving out compiled code doesn't break anything.
@@ -454,36 +465,41 @@ class EncodingTest(Testing.ZopeTestCase.FunctionalTestCase):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
         self.app['object'].foo = '\xf6'
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<string encoding="string_escape">\\xf6</string>' in
-                     response.getBody())
+        self.assertTrue(
+            '<string encoding="string_escape">\\xf6</string>'
+            in response.getBody())
 
     def test_string_encoding_cdata(self):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
         self.app['object'].foo = '<\xf6&>'
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<string encoding="string_escape"><![CDATA[<\\xf6&>]]></string>' in
-                     response.getBody())
+        self.assertTrue(
+            '<string encoding="string_escape"><![CDATA[<\\xf6&>]]></string>'
+            in response.getBody())
 
     def test_string_encoding_cdata_ampersand(self):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
         self.app['object'].foo = 'asdf&'
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<string><![CDATA[asdf&]]></string>' in
-                     response.getBody())
+        self.assertTrue(
+            '<string><![CDATA[asdf&]]></string>'
+            in response.getBody())
 
     def test_unicode_encoding(self):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
         self.app['object'].foo = u'\xf6'
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<unicode encoding="unicode_escape">\\xf6</unicode>' in
-                     response.getBody())
+        self.assertTrue(
+            '<unicode encoding="unicode_escape">\\xf6</unicode>'
+            in response.getBody())
 
     def test_unicode_encoding_cdata(self):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
         self.app['object'].foo = u'<\xf6&>'
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<unicode encoding="unicode_escape"><![CDATA[<\\xf6&>]]></unicode>' in
-                     response.getBody())
+        self.assertTrue(
+            '<unicode encoding="unicode_escape"><![CDATA[<\\xf6&>]]></unicode>'
+            in response.getBody())
 
     def test_no_newline_escape(self):
         self.app._setObject('object', OFS.SimpleItem.SimpleItem())
@@ -491,8 +507,9 @@ class EncodingTest(Testing.ZopeTestCase.FunctionalTestCase):
 Line 02
 Line 03"""
         response = self.publish('/object/@@toFS.snarf', basic='manager:asdf')
-        self.assert_('<string>Line 01\nLine 02\nLine 03</string>' in
-                     response.getBody())
+        self.assertTrue(
+            '<string>Line 01\nLine 02\nLine 03</string>'
+            in response.getBody())
 
 
 class BaseFileSystemTests(Testing.ZopeTestCase.FunctionalTestCase):
